@@ -41,10 +41,10 @@ extern "C" {
  *	#endif
  */
 
-#define CCOLAMD_DATE "Dec 9, 2022"
+#define CCOLAMD_DATE "Sept 8, 2023"
 #define CCOLAMD_MAIN_VERSION   3
-#define CCOLAMD_SUB_VERSION    0
-#define CCOLAMD_SUBSUB_VERSION 2
+#define CCOLAMD_SUB_VERSION    2
+#define CCOLAMD_SUBSUB_VERSION 0
 
 #define CCOLAMD_VERSION_CODE(main,sub) ((main) * 1000 + (sub))
 #define CCOLAMD_VERSION \
@@ -112,7 +112,6 @@ extern "C" {
 /* === Prototypes of user-callable routines ================================= */
 /* ========================================================================== */
 
-SUITESPARSE_PUBLIC 
 size_t ccolamd_recommended	/* returns recommended value of Alen, */
 				/* or 0 if input arguments are erroneous */
 (
@@ -121,7 +120,6 @@ size_t ccolamd_recommended	/* returns recommended value of Alen, */
     int n_col			/* number of columns in A */
 ) ;
 
-SUITESPARSE_PUBLIC 
 size_t ccolamd_l_recommended	/* returns recommended value of Alen, */
 				/* or 0 if input arguments are erroneous */
 (
@@ -130,19 +128,16 @@ size_t ccolamd_l_recommended	/* returns recommended value of Alen, */
     int64_t n_col		/* number of columns in A */
 ) ;
 
-SUITESPARSE_PUBLIC 
 void ccolamd_set_defaults	/* sets default parameters */
 (				/* knobs argument is modified on output */
     double knobs [CCOLAMD_KNOBS]	/* parameter settings for ccolamd */
 ) ;
 
-SUITESPARSE_PUBLIC 
 void ccolamd_l_set_defaults	/* sets default parameters */
 (				/* knobs argument is modified on output */
     double knobs [CCOLAMD_KNOBS]	/* parameter settings for ccolamd */
 ) ;
 
-SUITESPARSE_PUBLIC 
 int ccolamd			/* returns (1) if successful, (0) otherwise*/
 (				/* A and p arguments are modified on output */
     int n_row,			/* number of rows in A */
@@ -155,7 +150,6 @@ int ccolamd			/* returns (1) if successful, (0) otherwise*/
     int cmember [ ]		/* Constraint set of A, of size n_col */
 ) ;
 
-SUITESPARSE_PUBLIC 
 int ccolamd_l      /* as ccolamd w/ int64_t integers */
 (
     int64_t n_row,
@@ -168,7 +162,6 @@ int ccolamd_l      /* as ccolamd w/ int64_t integers */
     int64_t cmember [ ]
 ) ;
 
-SUITESPARSE_PUBLIC 
 int csymamd			/* return (1) if OK, (0) otherwise */
 (
     int n,			/* number of rows and columns of A */
@@ -185,7 +178,6 @@ int csymamd			/* return (1) if OK, (0) otherwise */
     int stype			/* 0: use both parts, >0: upper, <0: lower */
 ) ;
 
-SUITESPARSE_PUBLIC 
 int csymamd_l      /* as csymamd, w/ int64_t integers */
 (
     int64_t n,
@@ -200,25 +192,21 @@ int csymamd_l      /* as csymamd, w/ int64_t integers */
     int64_t stype
 ) ;
 
-SUITESPARSE_PUBLIC 
 void ccolamd_report
 (
     int stats [CCOLAMD_STATS]
 ) ;
 
-SUITESPARSE_PUBLIC 
 void ccolamd_l_report
 (
     int64_t stats [CCOLAMD_STATS]
 ) ;
 
-SUITESPARSE_PUBLIC 
 void csymamd_report
 (
     int stats [CCOLAMD_STATS]
 ) ;
 
-SUITESPARSE_PUBLIC 
 void csymamd_l_report
 (
     int64_t stats [CCOLAMD_STATS]
@@ -234,7 +222,6 @@ void csymamd_l_report
  * be called directly by the user.
  */
 
-SUITESPARSE_PUBLIC 
 int ccolamd2
 (				/* A and p arguments are modified on output */
     int n_row,			/* number of rows in A */
@@ -255,7 +242,6 @@ int ccolamd2
     int cmember [ ]		/* Constraint set of A */
 ) ;
 
-SUITESPARSE_PUBLIC 
 int ccolamd2_l     /* as ccolamd2, w/ int64_t integers */
 (
     int64_t n_row,
@@ -275,7 +261,6 @@ int ccolamd2_l     /* as ccolamd2, w/ int64_t integers */
     int64_t cmember [ ]
 ) ;
 
-SUITESPARSE_PUBLIC 
 void ccolamd_apply_order
 (
     int Front [ ],
@@ -285,7 +270,6 @@ void ccolamd_apply_order
     int nfr
 ) ;
 
-SUITESPARSE_PUBLIC 
 void ccolamd_l_apply_order
 (
     int64_t Front [ ],
@@ -295,7 +279,6 @@ void ccolamd_l_apply_order
     int64_t nfr
 ) ;
 
-SUITESPARSE_PUBLIC 
 void ccolamd_fsize
 (
     int nn,
@@ -306,7 +289,6 @@ void ccolamd_fsize
     int Npiv [ ]
 ) ;
 
-SUITESPARSE_PUBLIC 
 void ccolamd_l_fsize
 (
     int64_t nn,
@@ -317,7 +299,6 @@ void ccolamd_l_fsize
     int64_t Npiv [ ]
 ) ;
 
-SUITESPARSE_PUBLIC 
 void ccolamd_postorder
 (
     int nn,
@@ -332,7 +313,6 @@ void ccolamd_postorder
     int cmember [ ]
 ) ;
 
-SUITESPARSE_PUBLIC 
 void ccolamd_l_postorder
 (
     int64_t nn,
@@ -347,7 +327,6 @@ void ccolamd_l_postorder
     int64_t cmember [ ]
 ) ;
 
-SUITESPARSE_PUBLIC 
 int ccolamd_post_tree
 (
     int root,
@@ -358,7 +337,6 @@ int ccolamd_post_tree
     int Stack [ ]
 ) ;
 
-SUITESPARSE_PUBLIC 
 int64_t ccolamd_l_post_tree
 (
     int64_t root,
